package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````=1<``#0```#`@0````0`!30`(``)
M`"@`&P`:``$``'``>@```'H```!Z```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````,>@``#'H```4```````$`
M`0```)Q]``"<?0$`G'T!`*0"``"\$@``!@```````0`"````I'T``*1]`0"D
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DG'T`
M`)Q]`0"<?0$`9`(``&0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`$GVY1JV>B,?I1F,Z0\IUB^?S]=!$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%````!1````50``
M`%H```!;````8@```&,```!D````9@```&<`````````:0```&H```!K````
M;0```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````"4$@````````,`"P```````(`!```````#`!8`
MH@(`````````````$@```%`#`````````````!(````D`P`````````````B
M````:0,`````````````$0````8$`````````````!(````1````````````
M```@````%0(`````````````$@```/8"`````````````!(```!!`P``````
M```````2````$0$`````````````$@```(<#`````````````!$```"T````
M```````````2````O0(`````````````$@```(,!`````````````!(```"I
M`@`````````````2````A```````````````$@````P!`````````````!(`
M``#$`@`````````````2````A@(`````````````$@```$P"````````````
M`!(````D`@`````````````2````70(`````````````$@```&H"````````
M`````!(````!`0`````````````1````9P$`````````````$@```.,`````
M`````````!$````U`0`````````````2````_0(`````````````$@```.\"
M`````````````!$````&`P`````````````2````P@``````````````$@``
M`+$!`````````````!(````-`@`````````````2````G@$`````````````
M$@```-T"`````````````!(```#U`0`````````````2````J@$`````````
M````$@```%<#`````````````!(```!#`0`````````````2````+0``````
M````````(````'\"`````````````!(````V`@`````````````2````E`(`
M````````````$@```+P!`````````````!$```!D```````````````2````
M$P,`````````````$@```),``````````````!(```#\`0`````````````2
M````,P,`````````````$@```)\``````````````!(```!<`0``````````
M```2````9`(`````````````$@```)L"`````````````!(````B`0``````
M```````2````5@``````````````$@```!8!`````````````!(```"3`0``
M```````````2````KP(`````````````$@```/```````````````!(```!X
M`@`````````````2````20,`````````````$@```(T"`````````````!(`
M``!U`0`````````````2````<P``````````````$@```&H#````````````
M`"$````:`P`````````````2````U```````````````$@```%,!````````
M`````!(````\```````````````@````:P,`````````````$0```.4"````
M`````````!(````[`@`````````````2````<@(`````````````$@```.\!
M`````````````!(```#2`@`````````````2````0P(`````````````$@``
M`-L!`````````````!(```"[`P``6)`!```````0`!<`#P0``*TY``!0````
M$@`-`-T#``!0.@```````!(`#@`T!```?2\``'@'```2``T`9`,``,$5``"T
M`0``$@`-`.,#``"!*@``!````!(`#0"L`P``0(`!```````0`!<`H@0``(4J
M``"0`0``$@`-`)P$``"4$@```````!(`"P#/!```]38``+@"```2``T`H`,`
M`$"``0``````$``7`!L$```5+```%@```!(`#0!.!```6#H```0````1``\`
MS@,``%B0`0``````$``7`,8#``!8D`$``````!``%P":!```:2D``#@````2
M``T`KP0``.$N``"<````$@`-`,$$``!Q+@``8````!(`#0!!!````(`!````
M```0`!8`*`0``"TL``#`````$@`-`)D#``!`@`$``````!``%@"#!```/(`!
M``0````1`!8`TP,``$TZ```"````$@`-`',$```-.@``0````!(`#0!'!```
M=1<````````2``T`0P0```"``0``````(``6`/0#``#1+@``$````!(`#0"Z
M`P``6)`!```````0`!<`700``.TI``"4````$@`-`(T$``#M+```A`$``!(`
M#0``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I
M8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`
M;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!C;&]S
M961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B
M;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X
M85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M
M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M87)M:&8N
M<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B
M<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R
M7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#
M7S(N-````````````@`"``(``@`"`````P`"``(``@`$`````@````(`````
M``(``@`"``(``@`"`````````````@`"``(```````,````"``,``@`"````
M```"``(``@```````@````,``@```````@`"`````````````@````(``@`"
M```````"``(``````````@`"``(``@`#``(``@`#``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0!S`P``$````"`````4:6D-```$`.4$`````````0`!`,L!```0````
M(````!1I:0T```,`Y00````````!``$`&@(``!``````````%&EI#0```@#E
M!````````)Q]`0`7````H'T!`!<```#`?P$`%P```.A_`0`7````\'\!`!<`
M```$@`$`%P````R``0`7````$(`!`!<````8@`$`%P```!R``0`7````((`!
M`!<````D@`$`%P```"B``0`7````,(`!`!<````T@`$`%P```#R``0`7````
MQ'\!`!4%``#(?P$`%0@``,Q_`0`5#0``T'\!`!40``#4?P$`%1H``-A_`0`5
M'```W'\!`!4?``#@?P$`%2H``.1_`0`5+@``['\!`!4X``#T?P$`%4(``/A_
M`0`51P``_'\!`!5(``#`?@$`%@,``,1^`0`6!```R'X!`!8%``#,?@$`%@<`
M`-!^`0`6"0``U'X!`!8*``#8?@$`%@L``-Q^`0`6#```X'X!`!8.``#D?@$`
M%@\``.A^`0`6$0``['X!`!82``#P?@$`%A,``/1^`0`6%```^'X!`!85``#\
M?@$`%A8```!_`0`6%P``!'\!`!88```(?P$`%AD```Q_`0`6&P``$'\!`!8=
M```4?P$`%AX``!A_`0`6(```''\!`!8A```@?P$`%B(``"1_`0`6(P``*'\!
M`!8D```L?P$`%B4``#!_`0`6)@``-'\!`!8G```X?P$`%B@``#Q_`0`6*0``
M0'\!`!8J``!$?P$`%BL``$A_`0`6+```3'\!`!8M``!0?P$`%B\``%1_`0`6
M,```6'\!`!8Q``!<?P$`%C(``&!_`0`6,P``9'\!`!8T``!H?P$`%C4``&Q_
M`0`6-@``<'\!`!8W``!T?P$`%CD``'A_`0`6.@``?'\!`!8[``"`?P$`%CP`
M`(1_`0`6/0``B'\!`!8^``",?P$`%C\``)!_`0`60```E'\!`!9!``"8?P$`
M%D0``)Q_`0`610``H'\!`!9&``"D?P$`%DD``*A_`0`62@``K'\!`!9+``"P
M?P$`%DP``+1_`0`630``N'\!`!9.``"\?P$`%D\```A`+>E'`0#K"("]Z`3@
M+>4$X)_E#N"/X`CPON4$;`$``,:/XA;*C.($_+SE`,:/XA;*C.+\^[SE`,:/
MXA;*C.+T^[SE`,:/XA;*C.+L^[SE`,:/XA;*C.+D^[SE`,:/XA;*C.+<^[SE
M`,:/XA;*C.+4^[SE`,:/XA;*C.+,^[SE`,:/XA;*C.+$^[SE`,:/XA;*C.*\
M^[SE`,:/XA;*C.*T^[SE`,:/XA;*C.*L^[SE`,:/XA;*C.*D^[SE`,:/XA;*
MC.*<^[SE>$?`1@#&C^(6RHSBD/N\Y0#&C^(6RHSBB/N\Y7A'P$8`QH_B%LJ,
MXGS[O.4`QH_B%LJ,XG3[O.4`QH_B%LJ,XFS[O.4`QH_B%LJ,XF3[O.4`QH_B
M%LJ,XES[O.4`QH_B%LJ,XE3[O.4`QH_B%LJ,XDS[O.4`QH_B%LJ,XD3[O.4`
MQH_B%LJ,XCS[O.4`QH_B%LJ,XC3[O.4`QH_B%LJ,XBS[O.4`QH_B%LJ,XB3[
MO.4`QH_B%LJ,XAS[O.4`QH_B%LJ,XA3[O.4`QH_B%LJ,X@S[O.4`QH_B%LJ,
MX@3[O.4`QH_B%LJ,XOSZO.4`QH_B%LJ,XO3ZO.4`QH_B%LJ,XNSZO.4`QH_B
M%LJ,XN3ZO.4`QH_B%LJ,XMSZO.4`QH_B%LJ,XM3ZO.4`QH_B%LJ,XLSZO.4`
MQH_B%LJ,XL3ZO.4`QH_B%LJ,XKSZO.4`QH_B%LJ,XK3ZO.5X1\!&`,:/XA;*
MC.*H^KSE`,:/XA;*C.*@^KSE`,:/XA;*C.*8^KSE`,:/XA;*C.*0^KSE`,:/
MXA;*C.*(^KSE`,:/XA;*C.*`^KSE`,:/XA;*C.)X^KSE`,:/XA;*C.)P^KSE
M`,:/XA;*C.)H^KSE`,:/XA;*C.)@^KSE`,:/XA;*C.)8^KSE`,:/XA;*C.)0
M^KSE`,:/XA;*C.)(^KSE`,:/XA;*C.)`^KSE`,:/XA;*C.(X^KSE`,:/XA;*
MC.(P^KSE`,:/XA;*C.(H^KSE`,:/XA;*C.(@^KSE`,:/XA;*C.(8^KSE`,:/
MXA;*C.(0^KSE`,:/XA;*C.((^KSE`,:/XA;*C.(`^KSE\+6)L%A,64M\1`60
M!)$%J`.2!*GF6`.J,V@'D__W1N]32E1+HEC@6!%&`O`'^E)+XU@?>``O:=!0
M2^58*&C_]]KOD/@.-`)&*&A#\`(#@O@.-/_WT.\%FP4SL_&`3Y#X#B1"\`$"
M@/@.)&G2F``$)__WX.Y"2@2=>D1"2Q%H>T1!2BQH>D1#8,#I`A(_2P6:>T0$
M8`$JP^D!<`K=ZQD`\0P!!>N"!5/X!$NK0D'X!$_YT3=/`O&`00`D`S%_1`"4
M0/@A0`-&/6D#,C))*$9Y1/_W,.\$1G"S+TT&KWU$*&G_]W[N+4@Y1GA$`/`M
M_^BQ*TM[1!AI__=&[O_W$.\'FC-H($::0BK1";#PO?_WANXD2GI$$&$@L__W
M+NX72^58*&C_]VCO@/B!=H?GZ&AHL0+P7/G<YSAI__<R[P1&R^<92QI(X5AX
M1/_WSNX82#E&>$0`\/G^Z&``*,G0Z.?_]R;N`2#_]Y;NZ&@!`!@!```X`0``
M0`$``"0!```@`0```&H!`%HG``!8)P``\&D!`,1I`0`/$P``I&D!`*@D``".
M:0$`;FD!`#`!``#*)0``W",``$_P``M/\``.`KQJ1@2T`;3?^"2@"*.:1-_X
M(,!:^`S`3?@$S09+6O@#,`9(6O@``/_W/N[_]^SN"&<!``P!```T`0``/`$`
M`!0PG^44()_E`S"/X`(@D^<``%+C'O\O`1C__^KH9@$`+`$```9(!TMX1`=*
M>T2#0GI$`]`%2]-8`[$81W!'`+]8:`$`5&@!`,1F`0`4`0``"$@)2WA$"4I[
M1!D:>D2)$`'KT7%)$`/0!4O36`.Q&$=P1P"_+&@!`"AH`0"89@$`1`$```BU
M"DL*2GM$>D0;>&NY"4O36".Q"$M[1!AH__<X[?_WO_\&2P$B>T0:<`B]]F<!
M`&AF`0`0`0``JF<!`-9G`0#$YP"_`````-_X=#S?^'0L>T0MZ?!/K?4E?9M8
M#?$(#`#Q0`4`\8`'9$8`)@&3&VBCDU7I`A((-:]"9F#F8`FZ3^H2(T_J`BX#
M]']##O1_#D/J$F,A8$/J`F,$\1`$0^H.`T3X"#SDT0SU_'QO1@`EAD8^1E?X
M"`\R;[-L9T6T:7%O@^H"`_)L@^H$`_1I@^H``X+J`0)Y:(+J!`)/ZM-T@NH!
M`L?XA%!$ZD($1.I#`\?X@##=T7!&WND"8][I`,0':4_JE@Z":4[J@WX"F4_J
MW&6'Z@()1_:9$P)JQ?:"(T7J1!7)&$7J3!6)&&D8A6D$F@GJ!@E.ZH9^B>H%
M"4_JG`41ZPD!A^H."$7JA'74&()I".H,"$7JC'6(Z@<(I!@&FH[J!0D4ZP@$
M3^KQ:!3K"`0)Z@$)$NL#"$_JL0&)Z@X"&.L'"-WX()!/ZO1J&.L"`H7J`0@2
MZPH"".H$"!GK`PE/ZK0$B.H%"!GK#@[=^"B03^KR:A[K"`Z!Z@0('NL*#@CJ
M`@@9ZP,)3^JR`HCJ`0@9ZP4%W?@PD$_J_FH5ZP@%A.H""!7K"@4(Z@X(&>L#
M"4_JO@Z(Z@0(&>L!`=WX.*`1ZP@!@NH."4_J]6@1ZP@(">H%"1KK`PI/ZK4!
MB>H""1KK!`3=^$"@CNH!!13K"01/ZOAI%.L)!`7J"`4:ZP,*3^JX"(7J#@4:
MZP("W?A(H%(9@>H("4_J]&55&0GJ!`D:ZP,*"D8:ZPX.3^JT`=WX4*")Z@($
M'NL$!$_J]6F(Z@$.%.L)!`[J!0X:ZP,)3^JU!1GK`@F.Z@@.0D;=^%B`3^KT
M:AGK#@Z!Z@4)'NL*#@GJ!`D8ZP,(W?A@H!CK`@A/ZK0"B>H!!$_J_FD8ZP0$
MA>H""!3K"00(Z@X(&NL#"4_JO@X9ZP$)B.H%""E&&IU/ZO1J&>L("(+J#@D8
MZPH(">H$">T8;1C=^'"@3^JT`8GJ`@0L&4_J^&F.Z@$%%.L)!`7J"`4:ZP,)
M3^JX"!GK`@ER1MWX>.!50$_J]&H9ZP4%@>H("17K"@4)Z@0)'NL##MWX@*`>
MZP(.3^JT`HGJ`01/ZO5I'NL$!(CJ`@X4ZPD$#NH%#AKK`PE/ZK4%CNH(#AGK
M`0E!1MWXB(!/ZO1J&>L."8+J!0X9ZPH)#NH$#ACK`PA/ZK0$CNH"#ACK`0'=
M^)"`3^KY:A'K#@&%Z@0.$>L*`0[J"0X8ZP,(3^JY"8[J!0X8ZP("W?B8@$_J
M\6H2ZPX"A.H)#A+K"@(.Z@$.&.L#"$_JL0$8ZP4%CNH$"-WXH.!/ZO)J%>L(
M"(GJ`048ZPH(%4`>ZP,.A>H)!1[K!`XJFT_JL@(>ZP4.3O:A-$_J^&7&]MED
M'NL%#H'J`@4;&87J"`43ZPD)+)M/ZK@(&>L%"4_J_F49ZP4)@NH(!1L9A>H.
M!5L8+IE/ZKX.6QE/ZOEE6QF(Z@X%"1F%Z@D%B1@PFD_JN0E-&4_J\V%M&([J
M"0$2&5E`$NL("#*:3^JS`QCK`0%/ZO5HB>H#"A'K"`$2&8KJ!0K=^-"`$NL.
M`D_JM05/ZO%N$NL*`A+K#@*#Z@4*&.L$#HKJ`0H>ZPD.W?C8@$_JL0%/ZO)I
M'NL*#MWX\*`>ZPD.A>H!"1CK!`B)Z@()&.L#`]WXX(`3ZPD)3^JR`T_J_F(9
MZP("@>H#"1CK!`B)Z@X)&.L%"#J=3^J^#ACK"0A/ZO)I&.L)"(/J#@DM&8GJ
M`@EI&$_JL@41ZPD!3^KX8HD8CNH%"1KK!`*)Z@@)W?CXH-(8$NL)`D_JN`-/
MZO%HA>H#"1+K"`(:ZP0(B>H!"=WX`*$8ZPX(3^JQ`4_J\FX8ZPD(&.L."(/J
M`0D:ZP0.B>H""1[K!0Y"G4_JL@(>ZPD.3^KX:=WX$*$>ZPD.@>H""2T9B>H(
M">L83^JX!1/K"0-/ZOYH$^L(`X+J!0D:ZP0(B>H."1CK`0'=^!BA$>L)"4_J
MO@%/ZO-NA>H!"!GK#@D:ZP0.'NL"`HCJ`PC=^"#A$NL("$_JLP)/ZOEC&.L#
M"('J`@H>ZP0#BNH)"ET9W?@HX4_JN0,5ZPH%3^KX:17K"06"Z@,)'NL$#HGJ
M"`D>ZP$!W?@PX4_JN`@1ZPD!3^KU:1'K"0&#Z@@)'NL$#HGJ!0D>ZP(.3II/
MZK4%'NL)#D_J\6D>ZPD.B.H%"1(9B>H!"=(84)M/ZK$!$NL)`D_J_FD2ZPD"
MA>H!"1L9B>H."1/K"`3=^$B!3^J^#D_J\FH4ZPD$2_;<0\CV&W,4ZPH$0>H.
M"1CK`PBJ1@GJ`@E/ZK(%&.L*`@'J#@K=^%"!2>H*"4[J!0H2ZPD"3^KT:1+K
M"0(*Z@0*#NH%"1CK`PA/ZK0$2NH)"ACK`0'=^%B11>H$"!KK`0%/ZO)J".H"
M"!'K"@$%Z@0*&>L#"4CJ"@@9ZPX.3^JR`ACK#@[=^&"!1.H""D_J\6D>ZPD.
M"NH!"@3J`@D8ZP,(3^JQ`4KJ"0H8ZP4%W?AHD4+J`0@:ZP4%3^K^:@CJ#@@5
MZPH%`NH!"AGK`PE(Z@H(&>L$!$_JO@X8ZP0$W?AP@4'J#@I/ZO5I%.L)!`KJ
M!0H!Z@X)&.L#"$_JM05*Z@D*&.L"`MWX>)%.Z@4(&NL"`D_J]&H(Z@0($NL*
M`@[J!0H9ZP,)2.H*"!GK`0%/ZK0$&.L!`=WX@(%%Z@0*3^KR:1'K"0$*Z@(*
M!>H$"1CK`PA/ZK("2NH)"ACK#@[=^(B11.H""!KK#@Y/ZO%J".H!"![K"@X9
MZP,)!.H""D_JL0%(Z@H*&>L%!=WXD)%"Z@$(&NL%!4_J_FH5ZPH%".H."`+J
M`0H9ZP,)3^J^#DCJ"@@9ZP0*9IQ!Z@X)3^KU:QCK"@@)Z@4)&.L+"`'J#@KD
M&$_JM05)Z@H*I!AHFD[J!0D:ZP0$3^KX:A3K"@0.Z@4+$NL#"@GJ"`E/ZK@"
M2>H+"1KK`0AJF47J`@H9ZP@)3^KT:`KJ!`H9ZP@)R1@%Z@((3^JT!$KJ"`@1
MZPX.;)E"Z@0*&.L.#D_J^6@>ZP@.`NH$"\D8"NH)"D_JN0A-&4KJ"PENF43J
M"`H9ZP4%3^K^:0KJ#@H5ZPD%!.H("<D83^J^#HD82NH)"G":2.H."QKK`0E/
MZO5J&>L*"0OJ!0'2&`CJ#@M/ZK4%0>H+"Q(9<IE.Z@4*3^KY9!OK`@(*Z@D*
M$AD.Z@4+R1A/ZKD$$>L("$KJ"PETF47J!`H9ZP@(3^KR:1CK"0@%Z@0+$>L#
M"0KJ`@I/ZK(!2NH+"AGK#@YVFD3J`0D:ZPX.3^KX:@GJ"`D>ZPH.!.H!"M(8
M3^JX"$GJ"@E2&7B=0>H("AGK`@)/ZOYI$NL)`@KJ#@KM&`'J"`-*Z@,*+1EZ
MFT_JO@X:ZP4%3/+6%$_J\FK,]F(D%>L*!8CJ#@D;&8GJ`@E9&'R;3^JR`D_J
M]6H1ZPD!CNH""1'K"@$;&8GJ!0D3ZP@(?IM/ZK4%&.L)"$_J\6D8ZPD(@NH%
M"1L9B>H!"1/K#@Z`FQ[K"0E/ZK$!3^KX;H7J`0H9ZPX.&QF:&(KJ"`J"FT_J
MN`@2ZPH*3^K^8AKK`@*!Z@@)&QF)Z@X)71F$FQ7K"0E/ZKX.3^KR91GK!06(
MZ@X)&QF)Z@()61B&FQ'K"0E/ZK("3^KU81GK`0&.Z@()&QF)Z@4)$^L("(B;
M&.L)"4_JM05/ZO%H&>L("(+J!0D;&8GJ`0D3ZPX.BIL>ZPD)3^JQ`4_J^&X9
MZPX.A>H!"1L9B>H("9H8C)L2ZPD)3^JX"$_J_F(9ZP("@>H("1L9B>H."5T9
MCIL5ZPD)3^J^#D_J\F49ZP4%B.H."1L9B>H""5D8D)L1ZPD)3^JR`D_J]6$9
MZP$!CNH""1L9B>H%"1/K"`B2FQCK"0E/ZK4%3^KQ:!GK"`B"Z@4)&QF)Z@$)
M$^L.#I2;'NL)"4_JL0%/ZOAN&>L.#H7J`0D;&8GJ"`F:&):;$NL)"4_JN`A/
MZOYB&>L"`H'J"`D;&8GJ#@E=&9B;%>L)"4_JO@Y/ZO)E&>L%!8CJ#@D;&8GJ
M`@E9&)J;$>L)"4_JL@)/ZO5A&>L!`8[J`@D;&8GJ!0D3ZP@(G)L8ZPD)3^JU
M!4_J\6@9ZP@(&QF"Z@4)$^L.#HGJ`0F>FQ[K"0E/ZK$!3^KX;AGK#@X;&87J
M`0F:&(GJ"`F@FQ+K"0)/ZK@(3^K^:1L92D2!Z@@$A.H.!%L9&QE/ZO)D(T1/
MZKX.$^L,`[(8`V``)(-I'NL'!X)@`FH8ZP,#!V&)&(-A1&`!8@&;HYK$8!MH
M1&&:0L1A1&(#T0WU)7V]Z/"/_O<V[R!F`0`8`0``+>GX0R!+>T0`*#C0'TJ;
M6-/X`)"Y\0`/,]`#>+/Q/048OP$E`"L(OP`EK;G9^`!`?+$'1HA&3D8J1CE&
M($;_]QCH$+EC73TK#]!6^`1/`"SRT2!&O>CX@P5&%?@!/P`K&+\]*_G1+1K@
MYP$UINL)!BQ$MA#(^`!@($:]Z/B#!$;GYTQ&Y><`OZ)9`0!(`0``\+6#L!5/
M!4852VQ&?T3^6#-H`9,A1BA&__>J_["Q$4L`F/M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&*$;_]Y3_`"CHT0&:,VB:0@'1`[#PO?[WO.X,60$`
M&`$``$@!```MZ?!/#$;?^%R1A;!62P5&^40*>%GX`V`]*@B_`30S:"!&`Y/^
M]QSO`JD'1BA&__=K_X!&`"A4T/[W$N^X0D?22DL"FEGX`Y!/ZH((*WBS\3T`
M&+\!(``K"+\`(#BQ*$80^`$_`"L8OSTK^=%`&P(WV?@`H#A$_O?0[DKX"```
M*&O0V?@`(&D<`I@K>%+X(``]*QB_`"L#<`G00AP1^`$[$$8`*QB_/2L"^`$[
M]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:,VB:0DK1!;"]Z/"/"/'_,!3X`3L`
M^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#"#LUM&`.!01E/X!"\`\0$*`"KXT0,P
M@``92GI$$VBSN0$C$V#^]X#N`9#PL4_JB@A91D)&_O?J[0&;R?@`,`KQ`0(`
M(4/X(A#-^`B@AN<!1EA&_O<H[@-&R?@``"BQ3^J*".SGFD8((-;G3_#_,+#G
M_O<$[J!8`0`8`0``2`$``#99`0`S2S1*>T0MZ?!/G["<6"-H'9,0L0-X!D8S
MN1V:(VB:0E31'["]Z/"/_O<P[@=&`"CST-_XI(#?^*20W_BDH/A$^43Z1#A&
M_O?&[JBS`/$3!4%&*$;^]WKM`"CST$E&*$;^]W3M`"CMT#!&_O=`[H-&*$;^
M]SSN6$0",/[W%.Y31D_P_S(!(0&5`):#1O[W3.Y91@*J`R#^][#N`3!81@70
M!IL#]'!#L_6`3PS0_O>R[5A&_O=P[<7G.$;^][SN,$;^]WKMJ>?_]YO_\>?^
M]Y3M.%<!`!@!``#6$@``V!(``-H2```42P%&,+5[1!-,G;`%1@,@:D8<62-H
M&Y/^]Y3N<+D$FP/T<$.S]2!/&+^S]8!/!]`;FB-HFD(+T1VP,+T`(/?G*$8"
M(?[W0NZP^H#P0`GOY_[W8.U25@$`&`$``"WI\$.M]8!=)DR#L"9+#?6`5GQ$
M`:V`1B1(YU@$-HE&0/;_<BE&>$0[:#-@_O=J[1]+`"@IW48>XUBJ71QHTK$&
M1C)&+R$H1O[W#.ZHL2!&_O=6[C-&*D9!1O[W(NX-]8!3!#,::#MHFD(8T0WU
M@%T#L+WH\(,`+N/1($;^]T#N2D9!1O[W..WIY^-8'&@@1O[W-NY*1D%&_O<N
M[=_G_O<,[0"_ZE4!`!@!``"^$0``(`$``!"U"$P(2WQ$XU@8:/[W'NX&2@=+
M!TFB6'M$>42]Z!!`_O>4O4)5`0`@`0``'`$``-@0```F$0``#4L.2GM$$+6"
ML)Q8(&C^]P+N__?9_R!H_O?\[0A+`"$(2GM$S>D`,0=)>D1Y1/[WGNT"L!"]
M`+\,50$`(`$``-(3```G#0``^!```"!*(4MZ1/"UK?4`7=58A[`-]0!2'4P4
M,@WU@%8K:'Q$$#838/[W&NT92T'R`0(!(7M$S>D`!`.L($;^]SKM($8Q1D_T
M@%+^]\+L!!X6VV`<_O?L[`=&*+$Q1B)&_O=J[``C.U4-]0!3.$84,QIH*VB:
M0@71#?4`70>P\+T`)_'G_O=^[,!4`0`8`0``WA```,`0``#_][2_5TM82GM$
M+>GP3ZWUA%V;6(.P!$8-]812!J]32`23!#(;:`U&>$0Y1A-@__<K_2\A!D8@
M1O[WWNR8L4Q((49X1/_WG/T@1@WUA%,$,QIH!)L;:)I"0/""@`WUA%T#L+WH
M\(\@1O[WNNQ!27E$@48H1O[W'.T`*.#0/DL%1M_X^+![1`63*WC[1-_X\*#Z
M1``K0-`NL2E&,$;^]]#K`"@_T"A&_O><[$(>JQBJ7"\J!M$`(1EP`3@3^`$M
M+RKYT`GQ`0,81+#U@%^WV@WQA`@L2@$A`I1Z1%-&`9)`1D_T@%(`E?[WFNPZ
M1D%&`R#^]_SL*+D[:0/T<$.S]0!/&=`A20`@>43^]]+L!48`+970*W@`*[[1
MYK%91C!&_O>0Z]"Y&4D`('E$_O?"[`5&`"WNT8/G`2%`1O[WM.P`*-_1$TA!
M1GA$__<:_4!&_O?(ZWKG!9T!(+/G748!(+#G_O?$ZRA4`0`8`0``1!```#80
M```:$```A`\``'X/``#\#P``O`\``((/``!@#P``,@\```-X.[%"'"\K"+\0
M1A+X`3L`*_C1<$<`OSBU^+$%>`1&Y;'^]Q3L`3@B&)1"#-(C7"\K-=%3'@+@
M$7@O*3#1HT(:1@/Q_S/WT91"#=$O+330'4B]Z#A`>$3^]W:[&TB]Z#A`>$3^
M]W"[`3H#X!%X+RD$T1I&E$("\?\S]],2&Y,<L_6`7XB_`"`)V!%((48!,D_T
M@%-X1`1&_O=0ZR!&.+U3'@+@$7@O*=[0G$(:1@/Q_S/WTY1"R=#6YP9(O>@X
M0'A$_O=!NP"_J@X``!(.``"L4P$`M`T``"WI\$&,L$9,`JU&3WQ$1DX,-']$
MW_@4@0_,^$2_60&N#\4/S-?X`,`/Q21H0$C-^"S`>$0L@/_W.?P^2'A$__<U
M_#U(>$3_]S'\/$AX1/_W+?P[2'A$__<I_#I(>$3_]R7\.4AX1/_W(?PX2'A$
M__<=_$!&__<:_#5(>$3_]Q;\-$AX1/_W$OPS2#%&>$3_]\7[&+$!1D!&__<\
M_"](,49X1/_WN_L@L0%&+4AX1/_W,?PL2#%&>$3_][#[B+$!1BE(>$3_]R;\
M*$DI2'E$>$3_]R#\"YH[:)I"'M$,L+WH\($D2#%&>$3_]YC[>+DB20HB#?$9
M`'E$_O?(ZP`HX]$>2`WQ(P%X1/_W!/S<YP%&&TAX1/_W_OO6Y_[WLNH`OV`-
M``"R40$`&`$``&(.``#Z#0``_`T``/P-````#@````X```@.``"<#0``!`X`
M``X.``"*#0``"`X```@.```0#@``$@X``#X-```L#@``A@T``/(-``#V#0``
M:@T``%X-```221-*>4032Q"U>T2,6(*P&&@C:`&30QP%T`&:(VB:0A+1`K`0
MO0Q(:49X1/_W-/LPL0!X,"@8OP`H%+\!(``@!DM[1!A@Z.?^]UCJ/%`!`!@!
M``"*40$`P@P``%)1`0`(M?[W#NK^]P#J`+$`:`B]($LA2GM$+>GP08:PG%@%
M1AY.!*DC:'Y$,$8%D__W!/LI1A"S`W@'1ONQ_O?4Z0"[*$;^]Z;J@$8X1O[W
MHNI`1`(P_O=ZZA)+3_#_,@*7>T3-Z0!3#TL!(7M$@$;^]Z[J048P1O_W7/L#
MX`M(>$3_]U?[!9HC:)I"`M$&L+WH\('^]P3JS$\!`!@!``#R#```V@L``-0+
M``"<#```+>GP3ZWU`4W?^/!6J;#?^/"F#?70>WU$W_CH-BH=!I#Z1`7Q$`P'
MRJOQ^`A:^`,PJ_'@!"@UJ_'L"1"N'T8+DXCH!P"\Z`\`U_@`X"=&#\<-]0%#
MG.@#`)PSP_@`X,?I``&5Z`<`B>@'`#%&W_B8!GA$__>+^B"Q`W@%1@`K0/"L
M@/_W9_\'1@`H`/"M@#A&_O<HZD```3#^]P#J.W@*D(.QW_AHE@J=^40`DRA&
M2T9/\/\R`2$"-?[W,NH7^`$_`"ORT5OXX`P8N13@5/@$#XBQ,4;_]UKZ!48`
M*/;0`W@`*_/0__?Z^P`H[]`H1O[W>ND$1IBY`"58^"5``"QJT"-X`"MGT"!&
M`37_]^?[`"CRT"!&_O=FZ0`H[=`$1B!&W_CL=?[WWNG=^"B0?T0%1DA&_O?8
MZ05$!?($12A&_O>NZ=_XT#5/\/\R`2%[1,WI`3??^,0US?@,D'M$`)2`1O[W
MWNE`1D_TX''^]^[I`3`%T?[WT.D":!$J0/!E@C)&048#(/[W3.H$1BBY,VD#
M]'!#L_6`3T;0W_B`)0$A!IL`)UKX`@#?^'@E&VAZ1,WX`(``:/[WYND-]0%#
M.$:<,QIH"YL;:)I"0/""@@WU`4TIL+WH\(\`)*'G__?#_BA&_O<`Z0=&Y^<%
M1@GKA0<$/U?X!`]PL3%&`37_]\?Y`"CVT`-X`"OST/[W[.@`*.S0!T8\YPT@
MW_@,=?[W0.E3(W]$"I`]Y[=I_O>DZ(="L]$S:</S"`.S]>!_K=$H1O[W+NDQ
M1@=&W_C@!'A$__>>^0`H`/""@`:;'6C^]\3H`48H1O_W4?P%1@`H=M`H1O[W
M.ND#*`9&$-G?^+`4!#@H1'E$_O=@Z$"Y!"X`\+B!+D06^`4\+RL`\+*!__<K
M_C"Y`48H1O[W].@*D``H6-'?^(`4W_B`!'E$W_A\9'A$W_A\I/_WW_E^1/[W
M`.G?^'`TW_AP%$_P_S)[1`&3W_AH-'E$S?@`@/I$`Y%[1`$AW_A<E/E$`I`X
M1O[W$NDS1D9&F$84X/[W!ND#:!$K%]'^]][H`33-^!"0*D8#E%-&S?@$@`$A
M`)8"D#A&_O?ZZ$_TX'$X1O[W".E#'`5&XM"P1D!&_O<DZ-_X"`0Y1GA$__>9
M^3A&__<&_B[G!IL=:(7GJ_$$"4_P_S-O\!$"`B0`E/[W?.A)1@8B"IC]]_;O
M&_@$/".YF?@!,$,K`/!L@0`D`"(`(P"4"IBK\<@&_O=FZ,RAT>D``<VCT^D`
M([1GQND"`:OQD`$,D<JAT>D``<;I!"/*H]/I`"/&Z08!R:'1Z0`!QND((P`B
M`",-E,;I"B/&Z0PC2^DR`<WI#GA/]`!"248*F/WWN.\$'G'=UND*`><`(D;C
M%\WI!B,[&`B3#9LU:W=K"9/=Z0@CBT((OX)"`M(!-4?Q``<&F[!O6@\'FT+J
MPP);#U49W>D($D/K!P<U8W=CQND*$@`H1]#`\4`'#)NG0DE&&$2HOR=&.D;]
M]Z+OLV\[1+-G0"N_T3!&Y!M/1/[W2_H_+"C=I/%`"@?Q@`@J\#\#!_%`#IA$
MKO%`!*OQD`P@:!`T5/@,'&5&5/@(+`SQ$`Q4^`0\=$4/Q?'1,$;^]ROZ!/%`
M#L9%YM%/ZIH48QRJZX04!^N#%SE&2",B1@R8_?>X[[1GA^=/1LKG"IBK\9`)
MW>D.>/[WE.BT:H`A-6O$\\4"4QPX*PGX`A``\Y*`">L#`,/Q.`(`(?[W(N@P
M1B(.AOAS4"L.AOAT(*OQ,`F&^'=`AOAP,"L,+0J&^'$PAOAR4",,)`J&^'4P
MAOAV0/[WXOE;^,C,J_%$`K5HJ_$("S1IL&E/ZAQ!47!/ZAQC,6HN#A9Q+@Q6
M<7E."_@\/-5Q?D0M"M1RE7$E#M!S%7(E#-%T)`I5<A5&E'($#A1S!`P`"E1S
MD'-,1@@.$'0(#`D*4'21=(+X`\!/ZAPL@O@"P`'@%?@!/P"3($8S1D_P_S(!
M(0(T_?>J[Z-%\M%A2$_P_S)@2P$A>$3-^`B0`Y![1,WX`(`X1@&3`".)^"@P
M6DM[1/WWDN^@Y@:;7F@`+C_T2:XP1OWW;.\#*'_V0ZY3200X,$1Y1/WWDNX`
M*`B_-48XYL/Q0`()ZP,``"']]Y#O,$;^]VCY2$8X(@`A_?>([V3G-$@!(0:;
M`"=:^```&VC-Z0""0TH`:'I$_?>0[ZCEF?@",$$K?_2/KIGX`S!#*W_TBJZ9
M^`0P2"M_](6NF?@%,$4K?_2`K@"43_#_,PJ<;_`Y`B!&_??F[DE&($8I(OWW
M8.XP2S!,3_#_,GM$`9,O2WQ$S?@(D`$AS?@`@#A&`Y1[1/WW*N\WYOWWCNZ)
MJ\WO`````/[<NI@`````=E0R$`````#PX=+#``````$C16<`````<E`!`!1/
M`0`8`0````L``-P+``!L"P``3`H``#(+```H`0``,`L``%P*``#F"@``N`H`
M`+()```D"0``T@@``((*``#`"```.`L``&X*```F"P``)`@```X'```\"```
MM`4``%('```F!P``0@8``.8$``!@!P``@`8``)=*F$DMZ?!/>D2'L)9+!*X"
MEE!8`6@#D`61U%@@:/WW4.\%1B!H_?=,[Y7X:#`Q1H#X:3"-2'A$_O?L_ABQ
M`W@Q*P#PZ8#_]]?Z(&C]]SCOATD+(P$B>43]]W#N`"ACT(1*`6EZ1-3X`*!2
M:-'X&(`!*EO=W_@`LD_T@&E_2\#R(`G[1``F>T0!)0"3*.`":-OX"`#4^`"@
MDVA0^"5P">H#`[/U@&\(OQ%I#-!01@&1_?<&[P&9`B,`(@EH_?<.[M3X`*`!
M1CA&_?>`[0";6V@`*$#PE(`!-0$VJT)`\X^`4$;]]^[N048`(S)&_?>L[@%&
M`"C+T6)*U/@`H'I$4FA1'K%"$M$!*A#=7DX!)5!&?D0`X"!H_??4[D%&_?>`
M[7-H`36K0O7<U/@`H%!&_??([E5)`R,!(GE$_?<`[@5&:+$@:/WWO.XK:5!*
M&6AZ1/WWLNTK:1MHFVA;`FS4(&C]]Z[N2DD#(P$B>43]]^;M!49XL4=(`IEX
M1/[W2_X&1B!H`"Y-T/WWG.XK:3)&&6C]]Y+M(&C]]Y3N/TU]1`9&(&C]]X[N
M/4D!(GE$_??P[3M*>D0!1C!&_?=^[2!H_?>`[@`B`ID#1C9(@_AI('A$_O<@
M_@1&Z&"8L4_TX'$@1OWW]NU#'!$H&+\!*R[8`YL%FAMHFD(GT0>PO>CPCQI&
M?N>H:/_W0/L$1NA@`"CDT25(>$3]]\[M0W@`*S_T%:\1Y_WW3NXA2RII>T2;
M:!!H&6C^]\7_K><@:/WW0NXK:1EH_??8[8KG_?<6[1A)`T882")&>41X1(EH
M"6C]]ZKMM$<!`!@!```@`0``%@0``*X%``#H2`$`RD@!`,9(`0!02`$`/$@!
M`-0$``#"!```K@0``(P"``"P1P$`<@0``(($```J`@``*@0``")'`0#X1@$`
M"@0``#BU!4;_]SSY`W@$1CNQ0APO*PB_%$82^`$[`"OXT?_W4?H`+1B_`"@`
MT3B]*W@`*_O0!DD@1@0B>43]]\CM`"CST2A&O>@X0/[WOKXP`@```DM[1!MH
M_?>YO`"_`D8!`"WI^$,'1@Q.B$8,39%&?D3]]SKL?41V&[80"M`$/0`D`315
M^`0_2D9!1CA&F$>F0O;1O>CX@P"_@D,!`'A#`0!P1P"_"$`MZ0B`O>@!``(`
M<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````+@```"XN```E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R
M;V,O)6DO)7,`97AE`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````
M)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)
M0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M
M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````05)'
M5@`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-#4```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-
M10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@!TG?]_`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"!&```01@```$````!`````0``
M`,L!```!````&@(```$```!S`P``#````)02```-````4#H``!D```"<?0$`
M&P````0````:````H'T!`!P````$````]?[_;[0!```%````@`D```8```"@
M`@``"@```.\$```+````$````!4``````````P```+1^`0`"``````(``!0`
M```1````%P```)00```1````K`\``!(```#H````$P````@````>````"```
M`/O__V\!```(_O__;TP/``#___]O`P```/#__V]P#@``^O__;Q``````````
M````````````````````````````````````````````````I'T!````````
M````H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2
M``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(`
M`*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``
MH!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@
M$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2
M``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``$TZ````````````
M```````````````````````````````````````-.@```````,$5````````
M````````````````!(`!`/_____$/0``C#H```````"L.P``L#L``+@]``#T
M.@``P#T```````"D/0``K#T```````#,/0``1T-#.B`H56)U;G1U+TQI;F%R
M;R`W+C,N,"TR,W5B=6YT=3(I(#<N,RXP`$=#0SH@*%5B=6YT=2],:6YA<F\@
M-RXS+C`M,39U8G5N='4S*2`W+C,N,`!!,@```&%E86)I``$H````!3<M00`&
M"@=!"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U
M=&5S````````````````````````````````````````````````````````
M``L````!`````@```%0!``!4`0``&0```````````````0`````````3````
M!P````(```!P`0``<`$``"````````````````0`````````(0````<````"
M````D`$``)`!```D```````````````$`````````#0```#V__]O`@```+0!
M``"T`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(`
M`.`&```&`````P````0````0````1@````,````"````@`D``(`)``#O!```
M```````````!`````````$X```#___]O`@```'`.``!P#@``W`````4`````
M`````@````(```!;````_O__;P(```!,#P``3`\``&`````&`````P````0`
M````````:@````D````"````K`\``*P/``#H````!0`````````$````"```
M`',````)````0@```)00``"4$`````(```4````5````!`````@```!\````
M`0````8```"4$@``E!(```P```````````````0`````````=P````$````&
M````H!(``*`2```@`P`````````````$````!````((````!````!@```,`5
M``#`%0``D"0`````````````"`````````"(`````0````8```!0.@``4#H`
M``@```````````````0`````````C@````$````"````6#H``%@Z``"H/P``
M```````````$`````````)8````!``!P@@````!Z````>@``"`````T`````
M````!`````````"A`````0````(````(>@``"'H```0```````````````0`
M````````JP````X````#````G'T!`)Q]```$```````````````$````!```
M`+<````/`````P```*!]`0"@?0``!```````````````!`````0```##````
M!@````,```"D?0$`I'T``!`!```&``````````0````(````S`````$````#
M````M'X!`+1^``!,`0`````````````$````!````-$````!`````P````"`
M`0``@```0```````````````!`````````#7````"`````,```!`@`$`0(``
M`!@0``````````````0`````````W`````$````P`````````$"```!6````
M```````````!`````0```.4````#``!P``````````"6@```,P``````````
M`````0`````````!`````P``````````````R8```/4```````````````$`
&````````
